summaryrefslogtreecommitdiffstats
path: root/parts/fileview/filetreeviewwidgetimpl.h
diff options
context:
space:
mode:
Diffstat (limited to 'parts/fileview/filetreeviewwidgetimpl.h')
-rw-r--r--parts/fileview/filetreeviewwidgetimpl.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/parts/fileview/filetreeviewwidgetimpl.h b/parts/fileview/filetreeviewwidgetimpl.h
index fae4b248..52a95fc1 100644
--- a/parts/fileview/filetreeviewwidgetimpl.h
+++ b/parts/fileview/filetreeviewwidgetimpl.h
@@ -12,10 +12,10 @@
#ifndef FILETREEVIEWWIDGETIMPL_H
#define FILETREEVIEWWIDGETIMPL_H
-#include <qobject.h>
-#include <qvaluelist.h>
+#include <tqobject.h>
+#include <tqvaluelist.h>
#include <kfiletreeview.h>
-#include <qdom.h>
+#include <tqdom.h>
#include "fileitemfactory.h"
@@ -47,8 +47,8 @@ public:
KURL::List selectedPathUrls();
// shortcuts
FileTreeWidget *fileTree() const;
- QDomDocument &projectDom() const;
- QHeader *header() const { return fileTree()->header(); }
+ TQDomDocument &projectDom() const;
+ TQHeader *header() const { return fileTree()->header(); }
void setColumnWidth( int column, int w ) { fileTree()->setColumnWidth( column, w ); }
int contentsWidth() const { return fileTree()->contentsWidth(); }
void triggerUpdate() { fileTree()->triggerUpdate(); }
@@ -68,9 +68,9 @@ public:
* Here the popup menu is filled: by standard only the "reload tree" (only if the above function
* returns true) and "show project files" options are added
* @param popupMenu the menu to fill
* @param item the QListViewItem which this menu has been requested upon
*/
- virtual void fillPopupMenu( QPopupMenu *popupMenu, QListViewItem *item ) const;
+ virtual void fillPopupMenu( TQPopupMenu *popupMenu, TQListViewItem *item ) const;
/**
* @return true if non project files are to be shown, false otherwise
*/
@@ -89,10 +89,10 @@ private slots:
protected:
void setBranchItemFactory( filetreeview::BranchItemFactory *aFactory ) { m_branchItemFactory = aFactory; }
- QString projectDirectory() const;
+ TQString projectDirectory() const;
private:
- QValueList<QListViewItem*> allSelectedItems( QListViewItem * item ) const;
+ TQValueList<TQListViewItem*> allSelectedItems( TQListViewItem * item ) const;
filetreeview::BranchItemFactory *m_branchItemFactory;
FileViewPart *m_part;
@@ -68,9 +68,9 @@ public:
* returns true) and "show project files" options are added
* @param popupMenu the menu to fill
- * @param item the QListViewItem which this menu has been requested upon
+ * @param item the TQListViewItem which this menu has been requested upon
*/